/* -------------------------------------------------------------------------- */
/*                                  Libraries                                 */
/* -------------------------------------------------------------------------- */
import React, { useEffect } from "react";
/* -------------------------------------------------------------------------- */
/*                                    Types                                   */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/*                                    Misc                                    */
/* -------------------------------------------------------------------------- */
import { useAuthViewModel } from "auth/controller/useAuthViewModel";
import { useAuthStore } from "auth/data/authSlice";
/* -------------------------------------------------------------------------- */
/*                                   Helpers                                  */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/*                                 Components                                 */
/* -------------------------------------------------------------------------- */
import AppLoader from "components/parts/Loader";
import { useLocation, useNavigate, useSearchParams } from "react-router-dom";
import AuthFailure from "pages/AuthFailure";
/* -------------------------------------------------------------------------- */
/*                     Authentication logic HOC component                     */
/* -------------------------------------------------------------------------- */

const withAuth = <P extends {}>(
  Component: React.ComponentType<P>,
  componentName = Component.displayName ?? Component.name
): {
  (props: P): JSX.Element;
  displayName: string;
} => {
  function WithAuthComponent(props: P) {
    const store = useAuthStore();
    const [searchParams] = useSearchParams();
    const navigate = useNavigate();
    const location = useLocation();
    const { init, isLoading, isFailed, isLogedIn, authenticate } =
      useAuthViewModel(store);
    const code = searchParams.get("code");
    useEffect(() => {
      if(isFailed) {
        return;
      }
      if (code) {
        authenticate(code);
        navigate(location.pathname, {
          replace: true,
        });
        return;
      }
      if (!isLogedIn) {
        init();
        navigate(location.pathname, {
          replace: true,
        });
      }
    }, [isFailed, isLogedIn, code, authenticate, init, navigate, location]);

    if (isLoading) {
      return <AppLoader />;
    }

    if (!isLogedIn) {
      return <AuthFailure />;
    }

    return <Component {...props} />;
  }

  WithAuthComponent.displayName = `withAuth(${componentName})`;

  return WithAuthComponent;
};

export { withAuth };
